@@ -141,6 +141,9 @@ public class ToolBoxPanel extends ContentPanel {
 		case MERGECOLUMNPANEL:
 			doMergeColumnTab(event);
 			break;
+		case GROUPBYPANEL:
+			doGroupByTab(event);
+			break;		
 		case LABELCOLUNPANEL:
 			doLabelColumnTab(event);
 			break;	
@@ -152,6 +155,13 @@ public class ToolBoxPanel extends ContentPanel {
 			break;	
 		case VALIDATIONSTASKSPANEL:
 			doValidationsTasksTab(event);
+			break;
+		case NORMALIZEPANEL:
+			doNormalizeTab(event);	
+			break;
+		case DENORMALIZEPANEL:
+			doDenormalizeTab(event);	
+			break;	
 		default:
 			break;
 		
@@ -275,6 +285,24 @@ public class ToolBoxPanel extends ContentPanel {
 		}
 	}
 	
+	protected void doGroupByTab(WidgetRequestEvent event){
+		Log.debug("WidgetRequestEvent.GroupByPanel : ["+event.getTrId()+"]");
+		if (uiStateType == UIStateType.TR_OPEN
+				|| uiStateType == UIStateType.TABLECURATION
+				|| uiStateType == UIStateType.TABLEUPDATE) {
+			if (state == ToolBoxPanelState.OPENED) {
+				toolBox.openGroupByTab(event.getTrId(), event.getColumnName());
+				Log.debug("ToolBoxPanelSTate.OPENED Add Tabs");
+			} else {
+				enable();
+				expand();
+				state = ToolBoxPanelState.OPENED;
+				toolBox.openGroupByTab(event.getTrId(), event.getColumnName());
+			}
+		} else {
+			Log.debug("ToolBoxPanel No table open");
+		}
+	}
 	
 	
 	protected void doLabelColumnTab(WidgetRequestEvent event){
@@ -376,6 +404,44 @@ public class ToolBoxPanel extends ContentPanel {
 	}
 	
 	
+	protected void doNormalizeTab(WidgetRequestEvent event){
+		Log.debug("WidgetRequestEvent.NoramlizePanel : ["+event.getTrId()+"]");
+		if (uiStateType == UIStateType.TR_OPEN
+				|| uiStateType == UIStateType.TABLECURATION
+				|| uiStateType == UIStateType.TABLEUPDATE) {
+			if (state == ToolBoxPanelState.OPENED) {
+				toolBox.openNormalizeTab(event.getTrId());
+				Log.debug("ToolBoxPanelSTate.OPENED Normalize Tab");
+			} else {
+				enable();
+				expand();
+				state = ToolBoxPanelState.OPENED;
+				toolBox.openNormalizeTab(event.getTrId());
+			}
+		} else {
+			Log.debug("ToolBoxPanel No table open");
+		}
+	}
+	
+	protected void doDenormalizeTab(WidgetRequestEvent event){
+		Log.debug("WidgetRequestEvent.DenoramlizePanel : ["+event.getTrId()+"]");
+		if (uiStateType == UIStateType.TR_OPEN
+				|| uiStateType == UIStateType.TABLECURATION
+				|| uiStateType == UIStateType.TABLEUPDATE) {
+			if (state == ToolBoxPanelState.OPENED) {
+				toolBox.openDenormalizeTab(event.getTrId());
+				Log.debug("ToolBoxPanelSTate.OPENED Denormalize Tab");
+			} else {
+				enable();
+				expand();
+				state = ToolBoxPanelState.OPENED;
+				toolBox.openDenormalizeTab(event.getTrId());
+			}
+		} else {
+			Log.debug("ToolBoxPanel No table open");
+		}
+	}
+	
 	
 	protected void doPropertiesOpenTab(){
 		if (uiStateType == UIStateType.TR_OPEN
@@ -419,11 +485,14 @@ public class ToolBoxPanel extends ContentPanel {
 		toolBox.closeDeleteColumnPanel();
 		toolBox.closeSplitColumnPanel();
 		toolBox.closeMergeColumnPanel();
+		toolBox.closeGroupByPanel();
 		toolBox.closeLabelColumnPanel();
 		toolBox.closeChangeTableTypePanel();
 		toolBox.closeDuplicatesRowsPanel();
 		toolBox.closeValidationsTablePanel();
 		toolBox.closeValidationsTasksPanel();
+		toolBox.closeNormalizePanel();
+		toolBox.closeDenormalizePanel();
 		Log.debug("ToolBoxPanel Closed");
 	}
 	
